# Credits

## Development Lead

- [George Song](https://github.com/gsong)

## Contributors

- [Andreas Motl](https://github.com/amotl)
- [Daniel Blasco](https://github.com/dablak)
- [Felipe Eltermann](https://github.com/eltermann)
- [Hiro Kobashi](https://github.com/kobaski)
- [Mike Matheson](https://github.com/mmath)
- [Roberto Faga](https://github.com/rfaga)
- [Sotiris Fragkiskos](https://github.com/sfranky)
